@@ -1,7 +1,7 @@
 package App::LintPrereqs;
 
-our $DATE = '2016-09-27'; # DATE
-our $VERSION = '0.46'; # VERSION
+our $DATE = '2016-11-25'; # DATE
+our $VERSION = '0.47'; # VERSION
 
 use 5.010001;
 use strict;
@@ -597,7 +597,7 @@ sub lint_prereqs {
         # there is an unfixable error
         if (grep {!$_->{remedy_cmds}} @errs) {
             for my $e (@errs) {
-                $e->{remedy} .= " (can't fix automatically)" unless $e->{remedy_cmds};
+                $e->{remedy} = " (CAN'T FIX AUTOMATICALLY) $e->{remedy}" unless $e->{remedy_cmds};
             }
             $resmeta->{'cmdline.exit_code'} = 112;
         } else {
@@ -617,7 +617,7 @@ sub lint_prereqs {
                     for my $cmd (@{ $e->{remedy_cmds} }) {
                         system @$cmd;
                         if ($?) {
-                            $e->{remedy} .= " (fix failed: ".explain_child_error().")";
+                            $e->{remedy} = "(FIX FAILED: ".explain_child_error().") $e->{remedy}";
                             $resmeta->{'cmdline.exit_code'} = 1;
                             # restore dist.ini from backup
                             rename "dist.ini~", "dist.ini";
@@ -626,7 +626,7 @@ sub lint_prereqs {
                     }
                 }
                 for my $e (@errs) {
-                    $e->{remedy} .= " (fixed)";
+                    $e->{remedy} = "(DONE) $e->{remedy}";
                 }
                 $resmeta->{'cmdline.exit_code'} = 0;
                 # remove dist.ini~
@@ -657,7 +657,7 @@ App::LintPrereqs - Check extraneous/missing/incorrect prerequisites in dist.ini
 
 =head1 VERSION
 
-This document describes version 0.46 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-09-27.
+This document describes version 0.47 of App::LintPrereqs (from Perl distribution App-LintPrereqs), released on 2016-11-25.
 
 =head1 SYNOPSIS
 
